@@ -61,8 +61,14 @@ class Handler(logging.Handler):
         """
         super().__init__()
 
+        tenant = None
         json_key = json.loads(unpaddedbase64.decode_base64(api_key).decode("ascii"))
-        url = f"https://{json_key['host']}/loki/api/v1/push"
+        if not json_key['internal']:
+            url = f"https://{json_key['tenant']}.logship.io/loki/api/v1/push"
+        else:
+            url = f"http://distributor.ls-global/loki/api/v1/push"
+            tenant = {json_key['tenant']}
+
         auth = ('logship', api_key)
 
         if version is None and const.emitter_ver == "0":
@@ -77,7 +83,7 @@ class Handler(logging.Handler):
         version = version or const.emitter_ver
         if version not in self.emitters:
             raise ValueError("Unknown emitter version: {0}".format(version))
-        self.emitter = self.emitters[version](url, tags, auth)
+        self.emitter = self.emitters[version](url, tags, auth, tenant=tenant)
 
     def handleError(self, record):  # noqa: N802
         """Close emitter and let default handler take actions on error."""
